Keen | Table
Description: Bootstrap table examples

# Customer Relationship Management

New Order

### Table

Reports
Keen extends `Bootstrap Table` component with a variety of options to provide uniquely looking Table component that matches the Keen's design standards.
For more info please visit the plugin's Documentation.

### Basic Tables

Using the most basic table markup, here’s how tables look in Keen:

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Jhon | Stone | @jhon
2 | Lisa | Nilson | @lisa
3 | Larry | the Bird | @twitter

You can also invert the colors with light text on dark backgrounds with `.table-dark`.

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Jhon | Stone | @jhon
2 | Lisa | Nilson | @lisa
3 | Larry | the Bird | @twitter

### Table Head Options

Similar to default and inverse tables, use one of two modifier classes to make <thead>s appear light or dark gray.

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Jhon | Stone | @jhon
2 | Lisa | Nilson | @lisa
3 | Larry | the Bird | @twitter

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Jhon | Stone | @jhon
2 | Lisa | Nilson | @lisa
3 | Larry | the Bird | @twitter

### Small Table

Add `.table-sm` to make tables more compact by cutting cell padding in half.

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Jhon | Stone | @jhon
2 | Lisa | Nilson | @lisa
3 | Larry | the Bird | @twitter

### Striped Rows

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Jhon | Stone | @jhon
2 | Lisa | Nilson | @lisa
3 | Larry | the Bird | @twitter

### Bordered Table

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Jhon | Stone | @jhon
2 | Lisa | Nilson | @lisa
3 | Larry | the Bird | @twitter

### Hoverable Table

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Jhon | Stone | @jhon
2 | Lisa | Nilson | @lisa
3 | Larry | the Bird | @twitter

### Table Row States

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Jhon | Stone | @jhon
2 | Lisa | Nilson | @lisa
3 | Larry | the Bird | @twitter
4 | Nick | looper | @king
5 | Joan | thestar | @joan
6 | Sean | coder | @coder

### Responsive Tables

Create responsive tables by wrapping any table with `.table-responsive` `DIV` to make them scroll horizontally on small devices (under 768px)

# | Table heading | Table heading | Table heading | Table heading | Table heading | Table heading
--- | --- | --- | --- | --- | --- | ---
1 | Table cell | Table cell | Table cell | Table cell | Table cell | Table cell
2 | Table cell | Table cell | Table cell | Table cell | Table cell | Table cell
3 | Table cell | Table cell | Table cell | Table cell | Table cell | Table cell

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!